Class: SwaggerPetstoreOpenApi30::ApiResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- SwaggerPetstoreOpenApi30::ApiResponse
- Defined in:
- lib/swagger_petstore_open_api30/models/api_response.rb
Overview
ApiResponse Model.
Instance Attribute Summary collapse
-
#code ⇒ Integer
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(code = SKIP, type = SKIP, message = SKIP) ⇒ ApiResponse
constructor
A new instance of ApiResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(code = SKIP, type = SKIP, message = SKIP) ⇒ ApiResponse
Returns a new instance of ApiResponse.
47 48 49 50 51 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 47 def initialize(code = SKIP, type = SKIP, = SKIP) @code = code unless code == SKIP @type = type unless type == SKIP @message = unless == SKIP end |
Instance Attribute Details
#code ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 14 def code @code end |
#message ⇒ String
TODO: Write general description for this method
22 23 24 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 22 def @message end |
#type ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 18 def type @type end |
Class Method Details
.from_element(root) ⇒ Object
68 69 70 71 72 73 74 75 76 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 68 def self.from_element(root) code = XmlUtilities.from_element(root, 'code', Integer) type = XmlUtilities.from_element(root, 'type', String) = XmlUtilities.from_element(root, 'message', String) new(code, type, ) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. code = hash.key?('code') ? hash['code'] : SKIP type = hash.key?('type') ? hash['type'] : SKIP = hash.key?('message') ? hash['message'] : SKIP # Create object from extracted values. ApiResponse.new(code, type, ) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['code'] = 'code' @_hash['type'] = 'type' @_hash['message'] = 'message' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 34 def self.optionals %w[ code type message ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
95 96 97 98 99 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 95 def inspect class_name = self.class.name.split('::').last "<#{class_name} code: #{@code.inspect}, type: #{@type.inspect}, message:"\ " #{@message.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} code: #{@code}, type: #{@type}, message: #{@message}>" end |
#to_xml_element(doc, root_name) ⇒ Object
78 79 80 81 82 83 84 85 86 |
# File 'lib/swagger_petstore_open_api30/models/api_response.rb', line 78 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'code', code) XmlUtilities.add_as_subelement(doc, root, 'type', type) XmlUtilities.add_as_subelement(doc, root, 'message', ) root end |