Class: SwaggerPetstoreOpenApi30::PetController

Inherits:
BaseController show all
Defined in:
lib/swagger_petstore_open_api30/controllers/pet_controller.rb

Overview

PetController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from SwaggerPetstoreOpenApi30::BaseController

Instance Method Details

#add_pet(name, photo_urls, id: nil, category: nil, tags: nil, status: nil) ⇒ Pet

Add a new pet to the store. description here here

Parameters:

  • name (String)

    Required parameter: TODO: type description here

  • photo_urls (Array[String])

    Required parameter: TODO: type

  • id (Integer) (defaults to: nil)

    Optional parameter: TODO: type description here

  • category (Category) (defaults to: nil)

    Optional parameter: TODO: type description

  • tags (Array[Tag]) (defaults to: nil)

    Optional parameter: TODO: type description here

  • status (Status1Enum) (defaults to: nil)

    Optional parameter: pet status in the store

Returns:

  • (Pet)

    Response from the API call.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/swagger_petstore_open_api30/controllers/pet_controller.rb', line 66

def add_pet(name,
            photo_urls,
            id: nil,
            category: nil,
            tags: nil,
            status: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/pet',
                                 Server::DEFAULT)
               .form_param(new_parameter(name, key: 'name'))
               .form_param(new_parameter(photo_urls, key: 'photoUrls'))
               .form_param(new_parameter(id, key: 'id'))
               .form_param(new_parameter(category, key: 'category'))
               .form_param(new_parameter(tags, key: 'tags'))
               .form_param(new_parameter(status, key: 'status'))
               .header_param(new_parameter('application/x-www-form-urlencoded', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('petstore_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Pet.method(:from_hash))
                .local_error('400',
                             'Invalid input',
                             APIException)
                .local_error('422',
                             'Validation exception',
                             APIException)
                .local_error('default',
                             'Unexpected error',
                             APIException))
    .execute
end

#delete_pet(pet_id, api_key: nil) ⇒ void

This method returns an undefined value.

Delete a pet.

Parameters:

  • pet_id (Integer)

    Required parameter: Pet id to delete

  • api_key (String) (defaults to: nil)

    Optional parameter: TODO: type description here



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/swagger_petstore_open_api30/controllers/pet_controller.rb', line 214

def delete_pet(pet_id,
               api_key: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/pet/{petId}',
                                 Server::DEFAULT)
               .template_param(new_parameter(pet_id, key: 'petId')
                                .should_encode(true))
               .header_param(new_parameter(api_key, key: 'api_key'))
               .auth(Single.new('petstore_auth')))
    .response(new_response_handler
                .is_response_void(true)
                .local_error('400',
                             'Invalid pet value',
                             APIException)
                .local_error('default',
                             'Unexpected error',
                             APIException))
    .execute
end

#find_pets_by_status(status) ⇒ Array[Pet]

Multiple status values can be provided with comma separated strings. be considered for filter

Parameters:

  • status (Status2Enum)

    Required parameter: Status values that need to

Returns:

  • (Array[Pet])

    Response from the API call.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/swagger_petstore_open_api30/controllers/pet_controller.rb', line 104

def find_pets_by_status(status)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/pet/findByStatus',
                                 Server::DEFAULT)
               .query_param(new_parameter(status, key: 'status'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('petstore_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Pet.method(:from_hash))
                .is_response_array(true)
                .local_error('400',
                             'Invalid status value',
                             APIException)
                .local_error('default',
                             'Unexpected error',
                             APIException))
    .execute
end

#find_pets_by_tags(tags) ⇒ Array[Pet]

Multiple tags can be provided with comma separated strings. Use tag1, tag2, tag3 for testing.

Parameters:

  • tags (Array[String])

    Required parameter: Tags to filter by

Returns:

  • (Array[Pet])

    Response from the API call.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/swagger_petstore_open_api30/controllers/pet_controller.rb', line 129

def find_pets_by_tags(tags)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/pet/findByTags',
                                 Server::DEFAULT)
               .query_param(new_parameter(tags, key: 'tags'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('petstore_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Pet.method(:from_hash))
                .is_response_array(true)
                .local_error('400',
                             'Invalid tag value',
                             APIException)
                .local_error('default',
                             'Unexpected error',
                             APIException))
    .execute
end

#get_pet_by_id(pet_id) ⇒ Pet

Returns a single pet.

Parameters:

  • pet_id (Integer)

    Required parameter: ID of pet to return

Returns:

  • (Pet)

    Response from the API call.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/swagger_petstore_open_api30/controllers/pet_controller.rb', line 153

def get_pet_by_id(pet_id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/pet/{petId}',
                                 Server::DEFAULT)
               .template_param(new_parameter(pet_id, key: 'petId')
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Or.new('api_key', 'petstore_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Pet.method(:from_hash))
                .local_error('400',
                             'Invalid ID supplied',
                             APIException)
                .local_error('404',
                             'Pet not found',
                             APIException)
                .local_error('default',
                             'Unexpected error',
                             APIException))
    .execute
end

#update_pet(name, photo_urls, id: nil, category: nil, tags: nil, status: nil) ⇒ Pet

Update an existing pet by Id. description here here

Parameters:

  • name (String)

    Required parameter: TODO: type description here

  • photo_urls (Array[String])

    Required parameter: TODO: type

  • id (Integer) (defaults to: nil)

    Optional parameter: TODO: type description here

  • category (Category) (defaults to: nil)

    Optional parameter: TODO: type description

  • tags (Array[Tag]) (defaults to: nil)

    Optional parameter: TODO: type description here

  • status (Status1Enum) (defaults to: nil)

    Optional parameter: pet status in the store

Returns:

  • (Pet)

    Response from the API call.



19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/swagger_petstore_open_api30/controllers/pet_controller.rb', line 19

def update_pet(name,
               photo_urls,
               id: nil,
               category: nil,
               tags: nil,
               status: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PUT,
                                 '/pet',
                                 Server::DEFAULT)
               .form_param(new_parameter(name, key: 'name'))
               .form_param(new_parameter(photo_urls, key: 'photoUrls'))
               .form_param(new_parameter(id, key: 'id'))
               .form_param(new_parameter(category, key: 'category'))
               .form_param(new_parameter(tags, key: 'tags'))
               .form_param(new_parameter(status, key: 'status'))
               .header_param(new_parameter('application/x-www-form-urlencoded', key: 'content-type'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('petstore_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Pet.method(:from_hash))
                .local_error('400',
                             'Invalid ID supplied',
                             APIException)
                .local_error('404',
                             'Pet not found',
                             APIException)
                .local_error('422',
                             'Validation exception',
                             APIException)
                .local_error('default',
                             'Unexpected error',
                             APIException))
    .execute
end

#update_pet_with_form(pet_id, name: nil, status: nil) ⇒ Pet

Updates a pet resource based on the form data. updated updated updated

Parameters:

  • pet_id (Integer)

    Required parameter: ID of pet that needs to be

  • name (String) (defaults to: nil)

    Optional parameter: Name of pet that needs to be

  • status (String) (defaults to: nil)

    Optional parameter: Status of pet that needs to be

Returns:

  • (Pet)

    Response from the API call.



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/swagger_petstore_open_api30/controllers/pet_controller.rb', line 185

def update_pet_with_form(pet_id,
                         name: nil,
                         status: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/pet/{petId}',
                                 Server::DEFAULT)
               .template_param(new_parameter(pet_id, key: 'petId')
                                .should_encode(true))
               .query_param(new_parameter(name, key: 'name'))
               .query_param(new_parameter(status, key: 'status'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('petstore_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Pet.method(:from_hash))
                .local_error('400',
                             'Invalid input',
                             APIException)
                .local_error('default',
                             'Unexpected error',
                             APIException))
    .execute
end

#upload_file(pet_id, additional_metadata: nil, body: nil) ⇒ ApiResponse

Upload image of the pet. Metadata here

Parameters:

  • pet_id (Integer)

    Required parameter: ID of pet to update

  • additional_metadata (String) (defaults to: nil)

    Optional parameter: Additional

  • body (File | UploadIO) (defaults to: nil)

    Optional parameter: TODO: type description

Returns:



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/swagger_petstore_open_api30/controllers/pet_controller.rb', line 242

def upload_file(pet_id,
                additional_metadata: nil,
                body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/pet/{petId}/uploadImage',
                                 Server::DEFAULT)
               .template_param(new_parameter(pet_id, key: 'petId')
                                .should_encode(true))
               .query_param(new_parameter(, key: 'additionalMetadata'))
               .multipart_param(new_parameter(body, key: 'body')
                                 .default_content_type('application/octet-stream'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('petstore_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(ApiResponse.method(:from_hash))
                .local_error('400',
                             'No file uploaded',
                             APIException)
                .local_error('404',
                             'Pet not found',
                             APIException)
                .local_error('default',
                             'Unexpected error',
                             APIException))
    .execute
end