Class: SwaggerPetstoreOpenApi30::Tag
- Defined in:
- lib/swagger_petstore_open_api30/models/tag.rb
Overview
Tag Model.
Instance Attribute Summary collapse
-
#id ⇒ Integer
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
- .from_element(root) ⇒ Object
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id = SKIP, name = SKIP) ⇒ Tag
constructor
A new instance of Tag.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
- #to_xml_element(doc, root_name) ⇒ Object
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id = SKIP, name = SKIP) ⇒ Tag
Returns a new instance of Tag.
41 42 43 44 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 41 def initialize(id = SKIP, name = SKIP) @id = id unless id == SKIP @name = name unless name == SKIP end |
Instance Attribute Details
#id ⇒ Integer
TODO: Write general description for this method
14 15 16 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 14 def id @id end |
#name ⇒ String
TODO: Write general description for this method
18 19 20 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 18 def name @name end |
Class Method Details
.from_element(root) ⇒ Object
59 60 61 62 63 64 65 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 59 def self.from_element(root) id = XmlUtilities.from_element(root, 'id', Integer) name = XmlUtilities.from_element(root, 'name', String) new(id, name) end |
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : SKIP name = hash.key?('name') ? hash['name'] : SKIP # Create object from extracted values. Tag.new(id, name) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['name'] = 'name' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 29 def self.optionals %w[ id name ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, name: #{@name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, name: #{@name}>" end |
#to_xml_element(doc, root_name) ⇒ Object
67 68 69 70 71 72 73 74 |
# File 'lib/swagger_petstore_open_api30/models/tag.rb', line 67 def to_xml_element(doc, root_name) root = doc.create_element(root_name) XmlUtilities.add_as_subelement(doc, root, 'id', id) XmlUtilities.add_as_subelement(doc, root, 'name', name) root end |